@@ -45,12 +45,12 @@ config etc/rc.d/rc.cups.new
 ( cd usr/man/man1 ; ln -sf lp-cups.1.gz lp.1.gz )
 ( cd usr/man/man1 ; rm -rf cancel.1.gz )
 ( cd usr/man/man1 ; ln -sf cancel-cups.1.gz cancel.1.gz )
+( cd usr/man/man1 ; rm -rf cancel-cups.1.gz )
+( cd usr/man/man1 ; ln -sf lp.1.gz cancel-cups.1.gz )
 ( cd usr/man/man1 ; rm -rf lpq.1.gz )
 ( cd usr/man/man1 ; ln -sf lpq-cups.1.gz lpq.1.gz )
 ( cd usr/man/man1 ; rm -rf lpr.1.gz )
 ( cd usr/man/man1 ; ln -sf lpr-cups.1.gz lpr.1.gz )
-( cd usr/man/man1 ; rm -rf cancel-cups.1.gz )
-( cd usr/man/man1 ; ln -sf lp.1.gz cancel-cups.1.gz )
 ( cd usr/man/man1 ; rm -rf lprm.1.gz )
 ( cd usr/man/man1 ; ln -sf lprm-cups.1.gz lprm.1.gz )
 ( cd usr/man/man1 ; rm -rf lpstat.1.gz )
@@ -61,11 +61,17 @@ config etc/rc.d/rc.cups.new
 ( cd usr/man/man8 ; ln -sf accept.8.gz reject.8.gz )
 ( cd usr/man/man8 ; rm -rf disable.8.gz )
 ( cd usr/man/man8 ; ln -sf enable.8.gz disable.8.gz )
-( cd usr/man/fr/man1 ; rm -rf cancel.1 )
-( cd usr/man/fr/man1 ; ln -sf lp.1 cancel.1 )
-( cd usr/man/fr/man8 ; rm -rf reject.8 )
-( cd usr/man/fr/man8 ; ln -sf accept.8 reject.8 )
-( cd usr/man/fr/man8 ; rm -rf disable.8 )
-( cd usr/man/fr/man8 ; ln -sf enable.8 disable.8 )
+( cd usr/man/es/man1 ; rm -rf cancel.1.gz )
+( cd usr/man/es/man1 ; ln -sf lp.1.gz cancel.1.gz )
+( cd usr/man/es/man8 ; rm -rf reject.8.gz )
+( cd usr/man/es/man8 ; ln -sf accept.8.gz reject.8.gz )
+( cd usr/man/es/man8 ; rm -rf disable.8.gz )
+( cd usr/man/es/man8 ; ln -sf enable.8.gz disable.8.gz )
+( cd usr/man/fr/man1 ; rm -rf cancel.1.gz )
+( cd usr/man/fr/man1 ; ln -sf lp.1.gz cancel.1.gz )
+( cd usr/man/fr/man8 ; rm -rf reject.8.gz )
+( cd usr/man/fr/man8 ; ln -sf accept.8.gz reject.8.gz )
+( cd usr/man/fr/man8 ; rm -rf disable.8.gz )
+( cd usr/man/fr/man8 ; ln -sf enable.8.gz disable.8.gz )
 ( cd usr/doc ; rm -rf cups )
-( cd usr/doc ; ln -sf cups-1.1.21 cups )
+( cd usr/doc ; ln -sf cups-1.1.23 cups )
